pub struct CreateSecretRequest {
pub secret_name: String,
pub secret_value: String,
pub project_id: String,
pub environment: String,
pub path: Option<String>,
pub type: Option<String>,
pub secret_comment: Option<String>,
pub skip_multiline_encoding: Option<bool>,
}Expand description
Represents the parameters for a create secret request.
Use the CreateSecretRequest::builder() to construct this struct.
Fields
secret_name: Stringsecret_value: Stringproject_id: Stringenvironment: Stringpath: Option<String>type: Option<String>secret_comment: Option<String>skip_multiline_encoding: Option<bool>Implementations
Sourceimpl CreateSecretRequest
impl CreateSecretRequest
Sourcepub fn builder<SN, SV, PID, E>(
secret_name: SN,
secret_value: SV,
project_id: PID,
environment: E,
) -> CreateSecretBuilder<SN, SV, PID, E>
pub fn builder<SN, SV, PID, E>( secret_name: SN, secret_value: SV, project_id: PID, environment: E, ) -> CreateSecretBuilder<SN, SV, PID, E>
Creates a new builder for a create secret request.
Arguments
secret_name- The name of the secret to create.secret_value- The value of the secret to create.project_id- The ID of the project to insert the secret into.environment- The environment slug (e.g., “dev”, “prod”).