pub struct UpdateSecretRequest {
pub secret_name: String,
pub project_id: String,
pub environment: String,
pub new_secret_name: Option<String>,
pub secret_value: Option<String>,
pub path: Option<String>,
pub type: Option<String>,
pub secret_comment: Option<String>,
pub skip_multiline_encoding: Option<bool>,
}Expand description
Represents the parameters for a update secret request.
Use the UpdateSecretRequest::builder() to construct this struct.
Fields
secret_name: Stringproject_id: Stringenvironment: Stringnew_secret_name: Option<String>secret_value: Option<String>path: Option<String>type: Option<String>secret_comment: Option<String>skip_multiline_encoding: Option<bool>Implementations
Sourceimpl UpdateSecretRequest
impl UpdateSecretRequest
Sourcepub fn builder<SN, PID, E>(
secret_name: SN,
project_id: PID,
environment: E,
) -> UpdateSecretBuilder<SN, PID, E>
pub fn builder<SN, PID, E>( secret_name: SN, project_id: PID, environment: E, ) -> UpdateSecretBuilder<SN, PID, E>
Creates a new builder for a update secret request.
Arguments
secret_name- The name of the secret to update.project_id- The ID of the project to insert the secret into.environment- The environment slug (e.g., “dev”, “prod”).